@@ -93,7 +93,7 @@ marginalmeans <- function(model,
     # categorical variables, excluding response
     column_labels <- colnames(newdata)
     term_labels <- insight::find_terms(model, flatten = TRUE)
-    variables_categorical <- find_categorical(newdata)
+    variables_categorical <- find_categorical(newdata = newdata, model = model)
     variables_categorical <- setdiff(variables_categorical, insight::find_response(model, flatten = TRUE))
     variables_categorical <- intersect(variables_categorical, term_labels)
     if (length(variables_categorical) == 0) {
